@@ -2,6 +2,9 @@ library("repo.data")
 
 # Test deps without version number
 pd <- package_date("ggeasy")
+if (length(pd) == 1L && is.na(pd)) {
+    q("no")
+}
 stopifnot(length(pd) == 2L)
 stopifnot(names(pd) == c("Published", "deps_available"))
 # Test with a mix of version numbers and no versions
